/* IMPORTANT
 * This snapshot file is auto-generated, but designed for humans.
 * It should be checked into source control and tracked carefully.
 * Re-generate by setting TAP_SNAPSHOT=1 and running tests.
 * Make sure to inspect the output below.  Do not ignore changes!
 */
'use strict'
exports[`test/process-info-node.cts TAP basic instance stuff order=child,child2,parent,root > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child","child2","parent"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child","child2"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child,child2,parent,root > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child,child2,root,parent > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child","child2","parent"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child","child2"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child,child2,root,parent > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child,parent,child2,root > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child","parent","child2"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child","child2"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child,parent,child2,root > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child,parent,root,child2 > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child","parent","child2"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child","child2"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child,parent,root,child2 > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child,root,child2,parent > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child","child2","parent"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child","child2"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child,root,child2,parent > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child,root,parent,child2 > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child","parent","child2"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child","child2"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child,root,parent,child2 > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child2,child,parent,root > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child2","child","parent"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child2","child"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child2,child,parent,root > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child2,child,root,parent > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child2","child","parent"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child2","child"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child2,child,root,parent > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child2,parent,child,root > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child2","parent","child"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child2","child"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child2,parent,child,root > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child2,parent,root,child > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child2","parent","child"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child2","child"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child2,parent,root,child > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child2,root,child,parent > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child2","child","parent"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child2","child"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child2,root,child,parent > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child2,root,parent,child > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child2","parent","child"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child2","child"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=child2,root,parent,child > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=parent,child,child2,root > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["parent","child","child2"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child","child2"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=parent,child,child2,root > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=parent,child,root,child2 > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["parent","child","child2"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child","child2"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=parent,child,root,child2 > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=parent,child2,child,root > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["parent","child2","child"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child2","child"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=parent,child2,child,root > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=parent,child2,root,child > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["parent","child2","child"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child2","child"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=parent,child2,root,child > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=parent,root,child,child2 > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["parent","child","child2"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child","child2"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=parent,root,child,child2 > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=parent,root,child2,child > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["parent","child2","child"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child2","child"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=parent,root,child2,child > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=root,child,child2,parent > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child","child2","parent"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child","child2"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=root,child,child2,parent > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=root,child,parent,child2 > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child","parent","child2"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child","child2"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=root,child,parent,child2 > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=root,child2,child,parent > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child2","child","parent"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child2","child"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=root,child2,child,parent > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=root,child2,parent,child > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["child2","parent","child"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child2","child"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=root,child2,parent,child > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=root,parent,child,child2 > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["parent","child","child2"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child","child2"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=root,parent,child,child2 > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=root,parent,child2,child > after linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root","children":["parent"],"descendants":["parent","child2","child"]},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root","children":["child2","child"]},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`

exports[`test/process-info-node.cts TAP basic instance stuff order=root,parent,child2,child > before linking 1`] = `
{"root":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"root","files":["root.txt","shared.txt"],"sources":{},"root":"root"},"parent":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"parent","files":["parent.txt","shared.txt"],"sources":{},"parent":"root","root":"root"},"child":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child","files":["child.txt","shared.txt"],"sources":{},"parent":"parent","root":"root"},"child2":{"date":"2020-04-20T10:00:00.000Z","argv":["a"],"execArgv":["e"],"cwd":"/some/path","pid":12345,"ppid":12346,"uuid":"child2","files":["child2.txt","parent.txt"],"sources":{},"parent":"parent","root":"root","externalID":"child2-eid"}}
`
