/* IMPORTANT
 * This snapshot file is auto-generated, but designed for humans.
 * It should be checked into source control and tracked carefully.
 * Re-generate by setting TAP_SNAPSHOT=1 and running tests.
 * Make sure to inspect the output below.  Do not ignore changes!
 */
'use strict'
exports[`test/child_process.cts TAP --import exec > exec null options 1`] = `
Array [
  "exec",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --import exec > exec options 1`] = `
Array [
  "exec",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --import exec > exec, no options 1`] = `
Array [
  "exec",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --import exec > p exec null options 1`] = `
Array [
  "p exec",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import exec > p exec options 1`] = `
Array [
  "p exec",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --import exec > p exec, no options 1`] = `
Array [
  "p exec",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import execFile > execFile no args no options 1`] = `
Array [
  "execFile",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --import execFile > execFile no options 1`] = `
Array [
  "execFile",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --import execFile > execFile options 1`] = `
Array [
  "execFile",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --import execFile > execFile options no args 1`] = `
Array [
  "execFile",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --import execFile > execFile, null arg, no options 1`] = `
Array [
  "execFile",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --import execFile > execFile, null arg, options 1`] = `
Array [
  "execFile",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --import execFile > p execFile no options 1`] = `
Array [
  "p execFile",
  Array [
    "cmd",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import execFile > p execFile options 1`] = `
Array [
  "p execFile",
  Array [
    "cmd",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --import execFile > p execFile options no args 1`] = `
Array [
  "p execFile",
  Array [
    "cmd",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --import execFile > p execFile, null arg, no options 1`] = `
Array [
  "p execFile",
  Array [
    "cmd",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import execFile > p execFile, null arg, options 1`] = `
Array [
  "p execFile",
  Array [
    "cmd",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import execFileSync > execFileSync null arg no options 1`] = `
Array [
  "execFileSync",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import execFileSync > execFileSync null arg options 1`] = `
Array [
  "execFileSync",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import execFileSync > execFileSync, args and options 1`] = `
Array [
  "execFileSync",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --import execFileSync > execFileSync, no options 1`] = `
Array [
  "execFileSync",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import execFileSync > execFileSync, no options, no args 1`] = `
Array [
  "execFileSync",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import execFileSync > execFileSync, options 1`] = `
Array [
  "execFileSync",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --import execSync > execSync no options 1`] = `
Array [
  "execSync",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import execSync > execSync options 1`] = `
Array [
  "execSync",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --import fork > must match snapshot 1`] = `
Array [
  "fork",
  Array [
    "module",
    undefined,
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import fork > must match snapshot 2`] = `
Array [
  "fork",
  Array [
    "module",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import fork > must match snapshot 3`] = `
Array [
  "fork",
  Array [
    "module",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --import fork > must match snapshot 4`] = `
Array [
  "fork",
  Array [
    "module",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --import spawn > spawn, no args, no options 1`] = `
Array [
  "spawn",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import spawn > spawn, no args, options 1`] = `
Array [
  "spawn",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --import spawn > spawn, no options 1`] = `
Array [
  "spawn",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import spawn > spawn, options 1`] = `
Array [
  "spawn",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --import spawn > spawnSync no args no options 1`] = `
Array [
  "spawnSync",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import spawn > spawnSync no options 1`] = `
Array [
  "spawnSync",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --import spawn > spawnSync options 1`] = `
Array [
  "spawnSync",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --import spawn > spawnSync, no args, options 1`] = `
Array [
  "spawnSync",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--import=file://{CWD}/dist/esm/import.mjs\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader exec > exec null options 1`] = `
Array [
  "exec",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --loader exec > exec options 1`] = `
Array [
  "exec",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --loader exec > exec, no options 1`] = `
Array [
  "exec",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --loader exec > p exec null options 1`] = `
Array [
  "p exec",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader exec > p exec options 1`] = `
Array [
  "p exec",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader exec > p exec, no options 1`] = `
Array [
  "p exec",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader execFile > execFile no args no options 1`] = `
Array [
  "execFile",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --loader execFile > execFile no options 1`] = `
Array [
  "execFile",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --loader execFile > execFile options 1`] = `
Array [
  "execFile",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --loader execFile > execFile options no args 1`] = `
Array [
  "execFile",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --loader execFile > execFile, null arg, no options 1`] = `
Array [
  "execFile",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --loader execFile > execFile, null arg, options 1`] = `
Array [
  "execFile",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
    Function (),
  ],
]
`

exports[`test/child_process.cts TAP --loader execFile > p execFile no options 1`] = `
Array [
  "p execFile",
  Array [
    "cmd",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader execFile > p execFile options 1`] = `
Array [
  "p execFile",
  Array [
    "cmd",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader execFile > p execFile options no args 1`] = `
Array [
  "p execFile",
  Array [
    "cmd",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader execFile > p execFile, null arg, no options 1`] = `
Array [
  "p execFile",
  Array [
    "cmd",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader execFile > p execFile, null arg, options 1`] = `
Array [
  "p execFile",
  Array [
    "cmd",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader execFileSync > execFileSync null arg no options 1`] = `
Array [
  "execFileSync",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader execFileSync > execFileSync null arg options 1`] = `
Array [
  "execFileSync",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader execFileSync > execFileSync, args and options 1`] = `
Array [
  "execFileSync",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader execFileSync > execFileSync, no options 1`] = `
Array [
  "execFileSync",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader execFileSync > execFileSync, no options, no args 1`] = `
Array [
  "execFileSync",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader execFileSync > execFileSync, options 1`] = `
Array [
  "execFileSync",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader execSync > execSync no options 1`] = `
Array [
  "execSync",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader execSync > execSync options 1`] = `
Array [
  "execSync",
  Array [
    "cmd args",
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader fork > must match snapshot 1`] = `
Array [
  "fork",
  Array [
    "module",
    undefined,
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader fork > must match snapshot 2`] = `
Array [
  "fork",
  Array [
    "module",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader fork > must match snapshot 3`] = `
Array [
  "fork",
  Array [
    "module",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader fork > must match snapshot 4`] = `
Array [
  "fork",
  Array [
    "module",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader spawn > spawn, no args, no options 1`] = `
Array [
  "spawn",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader spawn > spawn, no args, options 1`] = `
Array [
  "spawn",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader spawn > spawn, no options 1`] = `
Array [
  "spawn",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader spawn > spawn, options 1`] = `
Array [
  "spawn",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader spawn > spawnSync no args no options 1`] = `
Array [
  "spawnSync",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader spawn > spawnSync no options 1`] = `
Array [
  "spawnSync",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader spawn > spawnSync options 1`] = `
Array [
  "spawnSync",
  Array [
    "cmd",
    Array [
      "args",
    ],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`

exports[`test/child_process.cts TAP --loader spawn > spawnSync, no args, options 1`] = `
Array [
  "spawnSync",
  Array [
    "cmd",
    Array [],
    Object {
      "env": Object {
        "_TAPJS_PROCESSINFO_EXCLUDE_": "/(^|[////])(node_modules|/.tap|tap-testdir-.*?|tap-snapshots|tests?|[^////]+/.test/.([cm]?[jt]s|[jt]sx?)|__tests?__)([////]|$)/i",
        "NODE_OPTIONS": "\\"--loader=file://{CWD}/dist/esm/loader-legacy.mjs\\" \\"--no-warnings\\"",
      },
      "stdio": "ignore",
    },
  ],
]
`
