/* IMPORTANT
 * This snapshot file is auto-generated, but designed for humans.
 * It should be checked into source control and tracked carefully.
 * Re-generate by setting TAP_SNAPSHOT=1 and running tests.
 * Make sure to inspect the output below.  Do not ignore changes!
 */
'use strict'
exports[`test/node-options-env.cts TAP no require.register available args has esm absolute > args has esm absolute 1`] = `
"--loader" "{LOADER ABS}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available args has esm absolute > args has esm absolute with -- 1`] = `
"--loader" "{LOADER ABS}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available args has esm absolute > args has esm absolute with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available args has esm absolute > args has esm absolute with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available args has esm absolute > args has esm absolute with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available args has esm absolute > args has esm absolute with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available args has esm absolute > args has esm absolute with trailing flag 1`] = `
"--loader" "{LOADER ABS}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available args has legacy loader relative > args has legacy loader relative 1`] = `
"--loader={LOADER REL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available args has legacy loader relative > args has legacy loader relative with -- 1`] = `
"--loader={LOADER REL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available args has legacy loader relative > args has legacy loader relative with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available args has legacy loader relative > args has legacy loader relative with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available args has legacy loader relative > args has legacy loader relative with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available args has legacy loader relative > args has legacy loader relative with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available args has legacy loader relative > args has legacy loader relative with trailing flag 1`] = `
"--loader={LOADER REL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available args has legacy loader url = > args has legacy loader url = 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available args has legacy loader url = > args has legacy loader url = with -- 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available args has legacy loader url = > args has legacy loader url = with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available args has legacy loader url = > args has legacy loader url = with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available args has legacy loader url = > args has legacy loader url = with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available args has legacy loader url = > args has legacy loader url = with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available args has legacy loader url = > args has legacy loader url = with trailing flag 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available doubledash > doubledash 1`] = `
"--import=whatever" "--" "--loader={LOADER URL}" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available doubledash > doubledash with -- 1`] = `
"--import=whatever" "--" "--loader={LOADER URL}" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available doubledash > doubledash with import 1`] = `
"--import=whatever" "--" "--loader={LOADER URL}"
`

exports[`test/node-options-env.cts TAP no require.register available doubledash > doubledash with import no = 1`] = `
"--import=whatever" "--" "--loader={LOADER URL}"
`

exports[`test/node-options-env.cts TAP no require.register available doubledash > doubledash with legacy loader 1`] = `
"--import=whatever" "--" "--loader={LOADER URL}"
`

exports[`test/node-options-env.cts TAP no require.register available doubledash > doubledash with legacy loader no = 1`] = `
"--import=whatever" "--" "--loader={LOADER URL}"
`

exports[`test/node-options-env.cts TAP no require.register available doubledash > doubledash with trailing flag 1`] = `
"--import=whatever" "--" "--loader={LOADER URL}" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available empty > empty 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available empty > empty with -- 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available empty > empty with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available empty > empty with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available empty > empty with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available empty > empty with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available empty > empty with trailing flag 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available empty no-warnings > empty no-warnings 1`] = `
"--no-warnings" "--loader={LOADER URL}"
`

exports[`test/node-options-env.cts TAP no require.register available empty no-warnings > empty no-warnings with -- 1`] = `
"--no-warnings" "--loader={LOADER URL}"
`

exports[`test/node-options-env.cts TAP no require.register available empty no-warnings > empty no-warnings with import 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available empty no-warnings > empty no-warnings with import no = 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available empty no-warnings > empty no-warnings with legacy loader 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available empty no-warnings > empty no-warnings with legacy loader no = 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available empty no-warnings > empty no-warnings with trailing flag 1`] = `
"--no-warnings" "--loader={LOADER URL}"
`

exports[`test/node-options-env.cts TAP no require.register available empty no-warnings=ExperimentalLoader > empty no-warnings=ExperimentalLoader 1`] = `
"--no-warnings=ExperimentalLoader" "--loader={LOADER URL}"
`

exports[`test/node-options-env.cts TAP no require.register available empty no-warnings=ExperimentalLoader > empty no-warnings=ExperimentalLoader with -- 1`] = `
"--no-warnings=ExperimentalLoader" "--loader={LOADER URL}"
`

exports[`test/node-options-env.cts TAP no require.register available empty no-warnings=ExperimentalLoader > empty no-warnings=ExperimentalLoader with import 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available empty no-warnings=ExperimentalLoader > empty no-warnings=ExperimentalLoader with import no = 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available empty no-warnings=ExperimentalLoader > empty no-warnings=ExperimentalLoader with legacy loader 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available empty no-warnings=ExperimentalLoader > empty no-warnings=ExperimentalLoader with legacy loader no = 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available empty no-warnings=ExperimentalLoader > empty no-warnings=ExperimentalLoader with trailing flag 1`] = `
"--no-warnings=ExperimentalLoader" "--loader={LOADER URL}"
`

exports[`test/node-options-env.cts TAP no require.register available esm absolute > esm absolute 1`] = `
"--loader" "{LOADER ABS}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm absolute > esm absolute with -- 1`] = `
"--loader" "{LOADER ABS}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm absolute > esm absolute with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm absolute > esm absolute with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm absolute > esm absolute with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm absolute > esm absolute with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm absolute > esm absolute with trailing flag 1`] = `
"--loader" "{LOADER ABS}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm relative > esm relative 1`] = `
"--loader={LOADER REL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm relative > esm relative with -- 1`] = `
"--loader={LOADER REL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm relative > esm relative with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm relative > esm relative with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm relative > esm relative with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm relative > esm relative with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm relative > esm relative with trailing flag 1`] = `
"--loader={LOADER REL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = > esm url = 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = > esm url = with -- 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = > esm url = with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm url = > esm url = with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm url = > esm url = with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm url = > esm url = with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm url = > esm url = with trailing flag 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = no warning > esm url = no warning 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = no warning > esm url = no warning with -- 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = no warning > esm url = no warning with import 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = no warning > esm url = no warning with import no = 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = no warning > esm url = no warning with legacy loader 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = no warning > esm url = no warning with legacy loader no = 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = no warning > esm url = no warning with trailing flag 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = no warning=exploader > esm url = no warning=exploader 1`] = `
"--loader={LOADER URL}" "--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = no warning=exploader > esm url = no warning=exploader with -- 1`] = `
"--loader={LOADER URL}" "--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = no warning=exploader > esm url = no warning=exploader with import 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = no warning=exploader > esm url = no warning=exploader with import no = 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = no warning=exploader > esm url = no warning=exploader with legacy loader 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = no warning=exploader > esm url = no warning=exploader with legacy loader no = 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available esm url = no warning=exploader > esm url = no warning=exploader with trailing flag 1`] = `
"--loader={LOADER URL}" "--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available esm url > esm url 1`] = `
"--loader" "{LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm url > esm url with -- 1`] = `
"--loader" "{LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available esm url > esm url with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm url > esm url with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm url > esm url with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm url > esm url with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available esm url > esm url with trailing flag 1`] = `
"--loader" "{LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available exp args esm absolute > exp args esm absolute 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available exp args esm absolute > exp args esm absolute with -- 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available exp args esm absolute > exp args esm absolute with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm absolute > exp args esm absolute with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm absolute > exp args esm absolute with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm absolute > exp args esm absolute with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm absolute > exp args esm absolute with trailing flag 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available exp args esm relative > exp args esm relative 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available exp args esm relative > exp args esm relative with -- 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available exp args esm relative > exp args esm relative with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm relative > exp args esm relative with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm relative > exp args esm relative with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm relative > exp args esm relative with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm relative > exp args esm relative with trailing flag 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available exp args esm url = > exp args esm url = 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available exp args esm url = > exp args esm url = with -- 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available exp args esm url = > exp args esm url = with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm url = > exp args esm url = with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm url = > exp args esm url = with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm url = > exp args esm url = with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm url = > exp args esm url = with trailing flag 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available exp args esm url > exp args esm url 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available exp args esm url > exp args esm url with -- 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available exp args esm url > exp args esm url with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm url > exp args esm url with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm url > exp args esm url with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm url > exp args esm url with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available exp args esm url > exp args esm url with trailing flag 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available has both > has both 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available has both > has both with -- 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available has both > has both with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available has both > has both with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available has both > has both with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available has both > has both with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available has both > has both with trailing flag 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import absolute > import absolute 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import absolute > import absolute with -- 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import absolute > import absolute with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available import absolute > import absolute with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available import absolute > import absolute with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available import absolute > import absolute with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available import absolute > import absolute with trailing flag 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import multiple times > import multiple times 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import multiple times > import multiple times with -- 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import multiple times > import multiple times with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available import multiple times > import multiple times with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available import multiple times > import multiple times with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available import multiple times > import multiple times with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available import multiple times > import multiple times with trailing flag 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import not found > import not found 1`] = `
"--import" "not foud" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import not found > import not found with -- 1`] = `
"--import" "not foud" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import not found > import not found with import 1`] = `
"--import" "not foud"
`

exports[`test/node-options-env.cts TAP no require.register available import not found > import not found with import no = 1`] = `
"--import" "not foud"
`

exports[`test/node-options-env.cts TAP no require.register available import not found > import not found with legacy loader 1`] = `
"--import" "not foud"
`

exports[`test/node-options-env.cts TAP no require.register available import not found > import not found with legacy loader no = 1`] = `
"--import" "not foud"
`

exports[`test/node-options-env.cts TAP no require.register available import not found > import not found with trailing flag 1`] = `
"--import" "not foud" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import relative > import relative 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import relative > import relative with -- 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import relative > import relative with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available import relative > import relative with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available import relative > import relative with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available import relative > import relative with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available import relative > import relative with trailing flag 1`] = `
"--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import value missing > import value missing 1`] = `
"--import" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import value missing > import value missing with -- 1`] = `
"--import" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available import value missing > import value missing with import 1`] = `
"--import"
`

exports[`test/node-options-env.cts TAP no require.register available import value missing > import value missing with import no = 1`] = `
"--import"
`

exports[`test/node-options-env.cts TAP no require.register available import value missing > import value missing with legacy loader 1`] = `
"--import"
`

exports[`test/node-options-env.cts TAP no require.register available import value missing > import value missing with legacy loader no = 1`] = `
"--import"
`

exports[`test/node-options-env.cts TAP no require.register available import value missing > import value missing with trailing flag 1`] = `
"--import" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url > legacy loader url 1`] = `
"--loader" "{LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url > legacy loader url with -- 1`] = `
"--loader" "{LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url > legacy loader url with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url > legacy loader url with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url > legacy loader url with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url > legacy loader url with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url > legacy loader url with trailing flag 1`] = `
"--loader" "{LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url with no-warnings > legacy loader url with no-warnings 1`] = `
"--loader" "{LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url with no-warnings > legacy loader url with no-warnings with -- 1`] = `
"--loader" "{LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url with no-warnings > legacy loader url with no-warnings with import 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url with no-warnings > legacy loader url with no-warnings with import no = 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url with no-warnings > legacy loader url with no-warnings with legacy loader 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url with no-warnings > legacy loader url with no-warnings with legacy loader no = 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url with no-warnings > legacy loader url with no-warnings with trailing flag 1`] = `
"--loader" "{LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url with no-warnings=ExperimentalLoader > legacy loader url with no-warnings=ExperimentalLoader 1`] = `
"--loader" "{LOADER URL}" "--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url with no-warnings=ExperimentalLoader > legacy loader url with no-warnings=ExperimentalLoader with -- 1`] = `
"--loader" "{LOADER URL}" "--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url with no-warnings=ExperimentalLoader > legacy loader url with no-warnings=ExperimentalLoader with import 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url with no-warnings=ExperimentalLoader > legacy loader url with no-warnings=ExperimentalLoader with import no = 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url with no-warnings=ExperimentalLoader > legacy loader url with no-warnings=ExperimentalLoader with legacy loader 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url with no-warnings=ExperimentalLoader > legacy loader url with no-warnings=ExperimentalLoader with legacy loader no = 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available legacy loader url with no-warnings=ExperimentalLoader > legacy loader url with no-warnings=ExperimentalLoader with trailing flag 1`] = `
"--loader" "{LOADER URL}" "--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP no require.register available loader multiple times > loader multiple times 1`] = `
"--loader" "{LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available loader multiple times > loader multiple times with -- 1`] = `
"--loader" "{LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available loader multiple times > loader multiple times with import 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available loader multiple times > loader multiple times with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available loader multiple times > loader multiple times with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available loader multiple times > loader multiple times with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP no require.register available loader multiple times > loader multiple times with trailing flag 1`] = `
"--loader" "{LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available loader not found > loader not found 1`] = `
"--loader" "not foud" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available loader not found > loader not found with -- 1`] = `
"--loader" "not foud" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available loader not found > loader not found with import 1`] = `
"--loader" "not foud"
`

exports[`test/node-options-env.cts TAP no require.register available loader not found > loader not found with import no = 1`] = `
"--loader" "not foud"
`

exports[`test/node-options-env.cts TAP no require.register available loader not found > loader not found with legacy loader 1`] = `
"--loader" "not foud"
`

exports[`test/node-options-env.cts TAP no require.register available loader not found > loader not found with legacy loader no = 1`] = `
"--loader" "not foud"
`

exports[`test/node-options-env.cts TAP no require.register available loader not found > loader not found with trailing flag 1`] = `
"--loader" "not foud" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available loader value missing > loader value missing 1`] = `
"--loader" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available loader value missing > loader value missing with -- 1`] = `
"--loader" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available loader value missing > loader value missing with import 1`] = `
"--loader"
`

exports[`test/node-options-env.cts TAP no require.register available loader value missing > loader value missing with import no = 1`] = `
"--loader"
`

exports[`test/node-options-env.cts TAP no require.register available loader value missing > loader value missing with legacy loader 1`] = `
"--loader"
`

exports[`test/node-options-env.cts TAP no require.register available loader value missing > loader value missing with legacy loader no = 1`] = `
"--loader"
`

exports[`test/node-options-env.cts TAP no require.register available loader value missing > loader value missing with trailing flag 1`] = `
"--loader" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available multiple import > multiple import 1`] = `
"--import" "some-file.ts" "--import" "/some/path/to/index.import" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available multiple import > multiple import with -- 1`] = `
"--import" "some-file.ts" "--import" "/some/path/to/index.import" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available multiple import > multiple import with import 1`] = `
"--import" "some-file.ts" "--import" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP no require.register available multiple import > multiple import with import no = 1`] = `
"--import" "some-file.ts" "--import" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP no require.register available multiple import > multiple import with legacy loader 1`] = `
"--import" "some-file.ts" "--import" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP no require.register available multiple import > multiple import with legacy loader no = 1`] = `
"--import" "some-file.ts" "--import" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP no require.register available multiple import > multiple import with trailing flag 1`] = `
"--import" "some-file.ts" "--import" "/some/path/to/index.import" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available multiple loaders > multiple loaders 1`] = `
"--loader" "some-file.ts" "--loader" "/some/path/to/index.import" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available multiple loaders > multiple loaders with -- 1`] = `
"--loader" "some-file.ts" "--loader" "/some/path/to/index.import" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available multiple loaders > multiple loaders with import 1`] = `
"--loader" "some-file.ts" "--loader" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP no require.register available multiple loaders > multiple loaders with import no = 1`] = `
"--loader" "some-file.ts" "--loader" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP no require.register available multiple loaders > multiple loaders with legacy loader 1`] = `
"--loader" "some-file.ts" "--loader" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP no require.register available multiple loaders > multiple loaders with legacy loader no = 1`] = `
"--loader" "some-file.ts" "--loader" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP no require.register available multiple loaders > multiple loaders with trailing flag 1`] = `
"--loader" "some-file.ts" "--loader" "/some/path/to/index.import" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available other import > other import 1`] = `
"--import" "some-file.ts" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available other import > other import with -- 1`] = `
"--import" "some-file.ts" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available other import > other import with import 1`] = `
"--import" "some-file.ts"
`

exports[`test/node-options-env.cts TAP no require.register available other import > other import with import no = 1`] = `
"--import" "some-file.ts"
`

exports[`test/node-options-env.cts TAP no require.register available other import > other import with legacy loader 1`] = `
"--import" "some-file.ts"
`

exports[`test/node-options-env.cts TAP no require.register available other import > other import with legacy loader no = 1`] = `
"--import" "some-file.ts"
`

exports[`test/node-options-env.cts TAP no require.register available other import > other import with trailing flag 1`] = `
"--import" "some-file.ts" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available other loader > other loader 1`] = `
"--loader" "some-file.ts" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available other loader > other loader with -- 1`] = `
"--loader" "some-file.ts" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available other loader > other loader with import 1`] = `
"--loader" "some-file.ts"
`

exports[`test/node-options-env.cts TAP no require.register available other loader > other loader with import no = 1`] = `
"--loader" "some-file.ts"
`

exports[`test/node-options-env.cts TAP no require.register available other loader > other loader with legacy loader 1`] = `
"--loader" "some-file.ts"
`

exports[`test/node-options-env.cts TAP no require.register available other loader > other loader with legacy loader no = 1`] = `
"--loader" "some-file.ts"
`

exports[`test/node-options-env.cts TAP no require.register available other loader > other loader with trailing flag 1`] = `
"--loader" "some-file.ts" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available some random stuff > some random stuff 1`] = `
"--x" "y" "-z" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available some random stuff > some random stuff with -- 1`] = `
"--x" "y" "-z" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP no require.register available some random stuff > some random stuff with import 1`] = `
"--x" "y" "-z"
`

exports[`test/node-options-env.cts TAP no require.register available some random stuff > some random stuff with import no = 1`] = `
"--x" "y" "-z"
`

exports[`test/node-options-env.cts TAP no require.register available some random stuff > some random stuff with legacy loader 1`] = `
"--x" "y" "-z"
`

exports[`test/node-options-env.cts TAP no require.register available some random stuff > some random stuff with legacy loader no = 1`] = `
"--x" "y" "-z"
`

exports[`test/node-options-env.cts TAP no require.register available some random stuff > some random stuff with trailing flag 1`] = `
"--x" "y" "-z" "--loader={LOADER URL}" "--no-warnings"
`

exports[`test/node-options-env.cts TAP with require.register available args has esm absolute > args has esm absolute 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available args has esm absolute > args has esm absolute with -- 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available args has esm absolute > args has esm absolute with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available args has esm absolute > args has esm absolute with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available args has esm absolute > args has esm absolute with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available args has esm absolute > args has esm absolute with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available args has esm absolute > args has esm absolute with trailing flag 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available args has legacy loader relative > args has legacy loader relative 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available args has legacy loader relative > args has legacy loader relative with -- 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available args has legacy loader relative > args has legacy loader relative with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available args has legacy loader relative > args has legacy loader relative with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available args has legacy loader relative > args has legacy loader relative with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available args has legacy loader relative > args has legacy loader relative with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available args has legacy loader relative > args has legacy loader relative with trailing flag 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available args has legacy loader url = > args has legacy loader url = 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available args has legacy loader url = > args has legacy loader url = with -- 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available args has legacy loader url = > args has legacy loader url = with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available args has legacy loader url = > args has legacy loader url = with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available args has legacy loader url = > args has legacy loader url = with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available args has legacy loader url = > args has legacy loader url = with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available args has legacy loader url = > args has legacy loader url = with trailing flag 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available doubledash > doubledash 1`] = `
"--import=whatever" "--" "--loader={LOADER URL}" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available doubledash > doubledash with -- 1`] = `
"--import=whatever" "--" "--loader={LOADER URL}" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available doubledash > doubledash with import 1`] = `
"--import=whatever" "--" "--loader={LOADER URL}"
`

exports[`test/node-options-env.cts TAP with require.register available doubledash > doubledash with import no = 1`] = `
"--import=whatever" "--" "--loader={LOADER URL}"
`

exports[`test/node-options-env.cts TAP with require.register available doubledash > doubledash with legacy loader 1`] = `
"--import=whatever" "--" "--loader={LOADER URL}"
`

exports[`test/node-options-env.cts TAP with require.register available doubledash > doubledash with legacy loader no = 1`] = `
"--import=whatever" "--" "--loader={LOADER URL}"
`

exports[`test/node-options-env.cts TAP with require.register available doubledash > doubledash with trailing flag 1`] = `
"--import=whatever" "--" "--loader={LOADER URL}" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available empty > empty 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available empty > empty with -- 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available empty > empty with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available empty > empty with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available empty > empty with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available empty > empty with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available empty > empty with trailing flag 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available empty no-warnings > empty no-warnings 1`] = `
"--no-warnings" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available empty no-warnings > empty no-warnings with -- 1`] = `
"--no-warnings" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available empty no-warnings > empty no-warnings with import 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP with require.register available empty no-warnings > empty no-warnings with import no = 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP with require.register available empty no-warnings > empty no-warnings with legacy loader 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP with require.register available empty no-warnings > empty no-warnings with legacy loader no = 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP with require.register available empty no-warnings > empty no-warnings with trailing flag 1`] = `
"--no-warnings" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available empty no-warnings=ExperimentalLoader > empty no-warnings=ExperimentalLoader 1`] = `
"--no-warnings=ExperimentalLoader" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available empty no-warnings=ExperimentalLoader > empty no-warnings=ExperimentalLoader with -- 1`] = `
"--no-warnings=ExperimentalLoader" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available empty no-warnings=ExperimentalLoader > empty no-warnings=ExperimentalLoader with import 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP with require.register available empty no-warnings=ExperimentalLoader > empty no-warnings=ExperimentalLoader with import no = 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP with require.register available empty no-warnings=ExperimentalLoader > empty no-warnings=ExperimentalLoader with legacy loader 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP with require.register available empty no-warnings=ExperimentalLoader > empty no-warnings=ExperimentalLoader with legacy loader no = 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP with require.register available empty no-warnings=ExperimentalLoader > empty no-warnings=ExperimentalLoader with trailing flag 1`] = `
"--no-warnings=ExperimentalLoader" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm absolute > esm absolute 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm absolute > esm absolute with -- 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm absolute > esm absolute with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm absolute > esm absolute with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm absolute > esm absolute with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm absolute > esm absolute with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm absolute > esm absolute with trailing flag 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm relative > esm relative 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm relative > esm relative with -- 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm relative > esm relative with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm relative > esm relative with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm relative > esm relative with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm relative > esm relative with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm relative > esm relative with trailing flag 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = > esm url = 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = > esm url = with -- 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = > esm url = with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm url = > esm url = with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm url = > esm url = with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm url = > esm url = with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm url = > esm url = with trailing flag 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = no warning > esm url = no warning 1`] = `
"--no-warnings" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = no warning > esm url = no warning with -- 1`] = `
"--no-warnings" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = no warning > esm url = no warning with import 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = no warning > esm url = no warning with import no = 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = no warning > esm url = no warning with legacy loader 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = no warning > esm url = no warning with legacy loader no = 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = no warning > esm url = no warning with trailing flag 1`] = `
"--no-warnings" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = no warning=exploader > esm url = no warning=exploader 1`] = `
"--no-warnings=ExperimentalLoader" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = no warning=exploader > esm url = no warning=exploader with -- 1`] = `
"--no-warnings=ExperimentalLoader" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = no warning=exploader > esm url = no warning=exploader with import 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = no warning=exploader > esm url = no warning=exploader with import no = 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = no warning=exploader > esm url = no warning=exploader with legacy loader 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = no warning=exploader > esm url = no warning=exploader with legacy loader no = 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP with require.register available esm url = no warning=exploader > esm url = no warning=exploader with trailing flag 1`] = `
"--no-warnings=ExperimentalLoader" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm url > esm url 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm url > esm url with -- 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available esm url > esm url with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm url > esm url with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm url > esm url with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm url > esm url with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available esm url > esm url with trailing flag 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available exp args esm absolute > exp args esm absolute 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available exp args esm absolute > exp args esm absolute with -- 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available exp args esm absolute > exp args esm absolute with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm absolute > exp args esm absolute with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm absolute > exp args esm absolute with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm absolute > exp args esm absolute with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm absolute > exp args esm absolute with trailing flag 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available exp args esm relative > exp args esm relative 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available exp args esm relative > exp args esm relative with -- 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available exp args esm relative > exp args esm relative with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm relative > exp args esm relative with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm relative > exp args esm relative with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm relative > exp args esm relative with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm relative > exp args esm relative with trailing flag 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available exp args esm url = > exp args esm url = 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available exp args esm url = > exp args esm url = with -- 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available exp args esm url = > exp args esm url = with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm url = > exp args esm url = with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm url = > exp args esm url = with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm url = > exp args esm url = with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm url = > exp args esm url = with trailing flag 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available exp args esm url > exp args esm url 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available exp args esm url > exp args esm url with -- 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available exp args esm url > exp args esm url with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm url > exp args esm url with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm url > exp args esm url with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm url > exp args esm url with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available exp args esm url > exp args esm url with trailing flag 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available has both > has both 1`] = `
"--import" "{IMPORT REL}"
`

exports[`test/node-options-env.cts TAP with require.register available has both > has both with -- 1`] = `
"--import" "{IMPORT REL}"
`

exports[`test/node-options-env.cts TAP with require.register available has both > has both with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available has both > has both with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available has both > has both with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available has both > has both with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available has both > has both with trailing flag 1`] = `
"--import" "{IMPORT REL}"
`

exports[`test/node-options-env.cts TAP with require.register available import absolute > import absolute 1`] = `
"--import" "{IMPORT ABS}"
`

exports[`test/node-options-env.cts TAP with require.register available import absolute > import absolute with -- 1`] = `
"--import" "{IMPORT ABS}"
`

exports[`test/node-options-env.cts TAP with require.register available import absolute > import absolute with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available import absolute > import absolute with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available import absolute > import absolute with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available import absolute > import absolute with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available import absolute > import absolute with trailing flag 1`] = `
"--import" "{IMPORT ABS}"
`

exports[`test/node-options-env.cts TAP with require.register available import multiple times > import multiple times 1`] = `
"--import" "{IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available import multiple times > import multiple times with -- 1`] = `
"--import" "{IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available import multiple times > import multiple times with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available import multiple times > import multiple times with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available import multiple times > import multiple times with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available import multiple times > import multiple times with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available import multiple times > import multiple times with trailing flag 1`] = `
"--import" "{IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available import not found > import not found 1`] = `
"--import" "not foud" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available import not found > import not found with -- 1`] = `
"--import" "not foud" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available import not found > import not found with import 1`] = `
"--import" "not foud"
`

exports[`test/node-options-env.cts TAP with require.register available import not found > import not found with import no = 1`] = `
"--import" "not foud"
`

exports[`test/node-options-env.cts TAP with require.register available import not found > import not found with legacy loader 1`] = `
"--import" "not foud"
`

exports[`test/node-options-env.cts TAP with require.register available import not found > import not found with legacy loader no = 1`] = `
"--import" "not foud"
`

exports[`test/node-options-env.cts TAP with require.register available import not found > import not found with trailing flag 1`] = `
"--import" "not foud" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available import relative > import relative 1`] = `
"--import={IMPORT REL}"
`

exports[`test/node-options-env.cts TAP with require.register available import relative > import relative with -- 1`] = `
"--import={IMPORT REL}"
`

exports[`test/node-options-env.cts TAP with require.register available import relative > import relative with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available import relative > import relative with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available import relative > import relative with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available import relative > import relative with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available import relative > import relative with trailing flag 1`] = `
"--import={IMPORT REL}"
`

exports[`test/node-options-env.cts TAP with require.register available import value missing > import value missing 1`] = `
"--import" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available import value missing > import value missing with -- 1`] = `
"--import" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available import value missing > import value missing with import 1`] = `
"--import"
`

exports[`test/node-options-env.cts TAP with require.register available import value missing > import value missing with import no = 1`] = `
"--import"
`

exports[`test/node-options-env.cts TAP with require.register available import value missing > import value missing with legacy loader 1`] = `
"--import"
`

exports[`test/node-options-env.cts TAP with require.register available import value missing > import value missing with legacy loader no = 1`] = `
"--import"
`

exports[`test/node-options-env.cts TAP with require.register available import value missing > import value missing with trailing flag 1`] = `
"--import" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url > legacy loader url 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url > legacy loader url with -- 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url > legacy loader url with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url > legacy loader url with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url > legacy loader url with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url > legacy loader url with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url > legacy loader url with trailing flag 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url with no-warnings > legacy loader url with no-warnings 1`] = `
"--no-warnings" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url with no-warnings > legacy loader url with no-warnings with -- 1`] = `
"--no-warnings" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url with no-warnings > legacy loader url with no-warnings with import 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url with no-warnings > legacy loader url with no-warnings with import no = 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url with no-warnings > legacy loader url with no-warnings with legacy loader 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url with no-warnings > legacy loader url with no-warnings with legacy loader no = 1`] = `
"--no-warnings"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url with no-warnings > legacy loader url with no-warnings with trailing flag 1`] = `
"--no-warnings" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url with no-warnings=ExperimentalLoader > legacy loader url with no-warnings=ExperimentalLoader 1`] = `
"--no-warnings=ExperimentalLoader" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url with no-warnings=ExperimentalLoader > legacy loader url with no-warnings=ExperimentalLoader with -- 1`] = `
"--no-warnings=ExperimentalLoader" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url with no-warnings=ExperimentalLoader > legacy loader url with no-warnings=ExperimentalLoader with import 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url with no-warnings=ExperimentalLoader > legacy loader url with no-warnings=ExperimentalLoader with import no = 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url with no-warnings=ExperimentalLoader > legacy loader url with no-warnings=ExperimentalLoader with legacy loader 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url with no-warnings=ExperimentalLoader > legacy loader url with no-warnings=ExperimentalLoader with legacy loader no = 1`] = `
"--no-warnings=ExperimentalLoader"
`

exports[`test/node-options-env.cts TAP with require.register available legacy loader url with no-warnings=ExperimentalLoader > legacy loader url with no-warnings=ExperimentalLoader with trailing flag 1`] = `
"--no-warnings=ExperimentalLoader" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available loader multiple times > loader multiple times 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available loader multiple times > loader multiple times with -- 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available loader multiple times > loader multiple times with import 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available loader multiple times > loader multiple times with import no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available loader multiple times > loader multiple times with legacy loader 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available loader multiple times > loader multiple times with legacy loader no = 1`] = `

`

exports[`test/node-options-env.cts TAP with require.register available loader multiple times > loader multiple times with trailing flag 1`] = `
"--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available loader not found > loader not found 1`] = `
"--loader" "not foud" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available loader not found > loader not found with -- 1`] = `
"--loader" "not foud" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available loader not found > loader not found with import 1`] = `
"--loader" "not foud"
`

exports[`test/node-options-env.cts TAP with require.register available loader not found > loader not found with import no = 1`] = `
"--loader" "not foud"
`

exports[`test/node-options-env.cts TAP with require.register available loader not found > loader not found with legacy loader 1`] = `
"--loader" "not foud"
`

exports[`test/node-options-env.cts TAP with require.register available loader not found > loader not found with legacy loader no = 1`] = `
"--loader" "not foud"
`

exports[`test/node-options-env.cts TAP with require.register available loader not found > loader not found with trailing flag 1`] = `
"--loader" "not foud" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available loader value missing > loader value missing 1`] = `
"--loader" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available loader value missing > loader value missing with -- 1`] = `
"--loader" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available loader value missing > loader value missing with import 1`] = `
"--loader"
`

exports[`test/node-options-env.cts TAP with require.register available loader value missing > loader value missing with import no = 1`] = `
"--loader"
`

exports[`test/node-options-env.cts TAP with require.register available loader value missing > loader value missing with legacy loader 1`] = `
"--loader"
`

exports[`test/node-options-env.cts TAP with require.register available loader value missing > loader value missing with legacy loader no = 1`] = `
"--loader"
`

exports[`test/node-options-env.cts TAP with require.register available loader value missing > loader value missing with trailing flag 1`] = `
"--loader" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available multiple import > multiple import 1`] = `
"--import" "some-file.ts" "--import" "/some/path/to/index.import" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available multiple import > multiple import with -- 1`] = `
"--import" "some-file.ts" "--import" "/some/path/to/index.import" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available multiple import > multiple import with import 1`] = `
"--import" "some-file.ts" "--import" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP with require.register available multiple import > multiple import with import no = 1`] = `
"--import" "some-file.ts" "--import" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP with require.register available multiple import > multiple import with legacy loader 1`] = `
"--import" "some-file.ts" "--import" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP with require.register available multiple import > multiple import with legacy loader no = 1`] = `
"--import" "some-file.ts" "--import" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP with require.register available multiple import > multiple import with trailing flag 1`] = `
"--import" "some-file.ts" "--import" "/some/path/to/index.import" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available multiple loaders > multiple loaders 1`] = `
"--loader" "some-file.ts" "--loader" "/some/path/to/index.import" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available multiple loaders > multiple loaders with -- 1`] = `
"--loader" "some-file.ts" "--loader" "/some/path/to/index.import" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available multiple loaders > multiple loaders with import 1`] = `
"--loader" "some-file.ts" "--loader" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP with require.register available multiple loaders > multiple loaders with import no = 1`] = `
"--loader" "some-file.ts" "--loader" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP with require.register available multiple loaders > multiple loaders with legacy loader 1`] = `
"--loader" "some-file.ts" "--loader" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP with require.register available multiple loaders > multiple loaders with legacy loader no = 1`] = `
"--loader" "some-file.ts" "--loader" "/some/path/to/index.import"
`

exports[`test/node-options-env.cts TAP with require.register available multiple loaders > multiple loaders with trailing flag 1`] = `
"--loader" "some-file.ts" "--loader" "/some/path/to/index.import" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available other import > other import 1`] = `
"--import" "some-file.ts" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available other import > other import with -- 1`] = `
"--import" "some-file.ts" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available other import > other import with import 1`] = `
"--import" "some-file.ts"
`

exports[`test/node-options-env.cts TAP with require.register available other import > other import with import no = 1`] = `
"--import" "some-file.ts"
`

exports[`test/node-options-env.cts TAP with require.register available other import > other import with legacy loader 1`] = `
"--import" "some-file.ts"
`

exports[`test/node-options-env.cts TAP with require.register available other import > other import with legacy loader no = 1`] = `
"--import" "some-file.ts"
`

exports[`test/node-options-env.cts TAP with require.register available other import > other import with trailing flag 1`] = `
"--import" "some-file.ts" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available other loader > other loader 1`] = `
"--loader" "some-file.ts" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available other loader > other loader with -- 1`] = `
"--loader" "some-file.ts" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available other loader > other loader with import 1`] = `
"--loader" "some-file.ts"
`

exports[`test/node-options-env.cts TAP with require.register available other loader > other loader with import no = 1`] = `
"--loader" "some-file.ts"
`

exports[`test/node-options-env.cts TAP with require.register available other loader > other loader with legacy loader 1`] = `
"--loader" "some-file.ts"
`

exports[`test/node-options-env.cts TAP with require.register available other loader > other loader with legacy loader no = 1`] = `
"--loader" "some-file.ts"
`

exports[`test/node-options-env.cts TAP with require.register available other loader > other loader with trailing flag 1`] = `
"--loader" "some-file.ts" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available some random stuff > some random stuff 1`] = `
"--x" "y" "-z" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available some random stuff > some random stuff with -- 1`] = `
"--x" "y" "-z" "--import={IMPORT URL}"
`

exports[`test/node-options-env.cts TAP with require.register available some random stuff > some random stuff with import 1`] = `
"--x" "y" "-z"
`

exports[`test/node-options-env.cts TAP with require.register available some random stuff > some random stuff with import no = 1`] = `
"--x" "y" "-z"
`

exports[`test/node-options-env.cts TAP with require.register available some random stuff > some random stuff with legacy loader 1`] = `
"--x" "y" "-z"
`

exports[`test/node-options-env.cts TAP with require.register available some random stuff > some random stuff with legacy loader no = 1`] = `
"--x" "y" "-z"
`

exports[`test/node-options-env.cts TAP with require.register available some random stuff > some random stuff with trailing flag 1`] = `
"--x" "y" "-z" "--import={IMPORT URL}"
`
